pub enum ResponseCode {
Show 24 variants
Success = 0,
Continuation = 1,
NeedsAuthentication = 65_536,
Forbidden = 65_537,
Closing = 65_538,
Errno = 65_539,
AuthenticationFailed = 65_540,
Gone = 65_541,
NotFound = 65_542,
InternalError = 65_543,
ChannelDead = 65_544,
Aborted = 65_545,
ContinuationNotFound = 65_546,
OutOfRange = 65_547,
NoSpace = 65_548,
Conflict = 65_549,
Unlistable = 65_550,
NotEnabled = 131_072,
NotSupported = 131_073,
ParametersNotSupported = 131_074,
Invalid = 131_075,
TooLarge = 131_076,
TooManyMessages = 131_077,
InvalidParameters = 131_078,
}Expand description
The response codes for the protocol.
The response codes are based around IMAP’s response codes, and the top two bytes of the response indicates the type:
- 00: success
- 01: no (roughly, the request was understood, but not completed)
- 02: bad (roughly, the request was not understood)
- ff: extension message (dynamically allocated)
Variants
Success = 0
The request was successful. The response contains the requested data.
Continuation = 1
The request is incomplete, but is so far successful. The request should continue, referencing the ID of the last request.
NeedsAuthentication = 65_536
The request requires authentication.
The semantics for this message are equivalent to an HTTP 401 response.
Forbidden = 65_537
The message was not allowed.
The semantics for this message are equivalent to an HTTP 403 response.
Closing = 65_538
The server is shutting down.
Errno = 65_539
The message failed for a system error reason.
This is generally only useful for certain types of channels.
AuthenticationFailed = 65_540
Gone = 65_541
The other end of the channel has disappeared.
NotFound = 65_542
InternalError = 65_543
ChannelDead = 65_544
The channel has ceased to produce new data and this operation cannot complete.
Aborted = 65_545
The operation was aborted.
ContinuationNotFound = 65_546
There is no continuation with the specified parameters.
OutOfRange = 65_547
The result was out of range.
The semantics for this message are equivalent to ERANGE.
NoSpace = 65_548
There is no more space for the requested item.
Conflict = 65_549
The requested operation would conflict with something already existing.
The semantics for this message are equivalent to an HTTP 409 response.
Unlistable = 65_550
The contents of the object cannot be listed or specified by name.
For example, when using a Git-protocol credential helper, it is not possible to enumerate all credentials or pick a credential by ID.
NotEnabled = 131_072
The message type was not enabled.
NotSupported = 131_073
The message type or operation was not supported.
ParametersNotSupported = 131_074
The parameters were not supported.
Invalid = 131_075
The message type was received, but was not valid.
TooLarge = 131_076
The message was too large.
TooManyMessages = 131_077
There are too many pending messages.
InvalidParameters = 131_078
The parameters are supported, but not correct.
For example, if a selector is not valid for a channel, this message may be sent.